/*******************************************************************************
* File Name: PeriodISR.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <PeriodISR.h>

#if !defined(PeriodISR__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START PeriodISR_intc` */
    
#include <project.h>

volatile uint16 PulsePeriodStart;   	// period time start
volatile uint16 PulsePeriodEnd;	        // period time end

volatile uint8 flgPerdstart;            // Flag indicating + edge of pulsein has occured
volatile uint8 flgPerdend;              // Flag indicating + edge of next pulse has occured, signifying end of pepriod

/* `#END` */

extern cyisraddress CyRamVectors[CYINT_IRQ_BASE + CY_NUM_INTERRUPTS];

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: PeriodISR_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_Start(void)
{
    /* For all we know the interrupt is active. */
    PeriodISR_Disable();

    /* Set the ISR to point to the PeriodISR Interrupt. */
    PeriodISR_SetVector(&PeriodISR_Interrupt);

    /* Set the priority. */
    PeriodISR_SetPriority((uint8)PeriodISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    PeriodISR_Enable();
}


/*******************************************************************************
* Function Name: PeriodISR_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    PeriodISR_Disable();

    /* Set the ISR to point to the PeriodISR Interrupt. */
    PeriodISR_SetVector(address);

    /* Set the priority. */
    PeriodISR_SetPriority((uint8)PeriodISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    PeriodISR_Enable();
}


/*******************************************************************************
* Function Name: PeriodISR_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_Stop(void)
{
    /* Disable this interrupt. */
    PeriodISR_Disable();

    /* Set the ISR to point to the passive one. */
    PeriodISR_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: PeriodISR_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for PeriodISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(PeriodISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START PeriodISR_Interrupt` */
    
     
    if ( flgPerdstart == 0 ) {                                      // Time to start a new period reading ?
     
        PulsePeriodStart = Counter_ReadCounter( );                  // Read counter at begining of period
        flgPerdstart = 1;                                           // Indicate first read has been done
    } else if ( ( flgPerdstart == 1 ) && ( flgPerdend == 0 ) ) {    // Read counter at end of period

        PulsePeriodEnd = Counter_ReadCounter( );                    // Read current counter value for start of period
        flgPerdend = 1;                                             // Read current counter value for end of period
    }
//    PWMxIn_ClearInterrupt( );
    return;

    /* `#END` */
}


/*******************************************************************************
* Function Name: PeriodISR_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling PeriodISR_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use PeriodISR_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_SetVector(cyisraddress address)
{
    CyRamVectors[CYINT_IRQ_BASE + PeriodISR__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: PeriodISR_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress PeriodISR_GetVector(void)
{
    return CyRamVectors[CYINT_IRQ_BASE + PeriodISR__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: PeriodISR_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling PeriodISR_Start
*   or PeriodISR_StartEx will override any effect this method would 
*   have had. This method should only be called after PeriodISR_Start or 
*   PeriodISR_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 3, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_SetPriority(uint8 priority)
{
	uint8 interruptState;
    uint32 priorityOffset = ((PeriodISR__INTC_NUMBER % 4u) * 8u) + 6u;
    
	interruptState = CyEnterCriticalSection();
    *PeriodISR_INTC_PRIOR = (*PeriodISR_INTC_PRIOR & (uint32)(~PeriodISR__INTC_PRIOR_MASK)) |
                                    ((uint32)priority << priorityOffset);
	CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: PeriodISR_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 3, 0 being the highest.
*
*******************************************************************************/
uint8 PeriodISR_GetPriority(void)
{
    uint32 priority;
	uint32 priorityOffset = ((PeriodISR__INTC_NUMBER % 4u) * 8u) + 6u;

    priority = (*PeriodISR_INTC_PRIOR & PeriodISR__INTC_PRIOR_MASK) >> priorityOffset;

    return (uint8)priority;
}


/*******************************************************************************
* Function Name: PeriodISR_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_Enable(void)
{
    /* Enable the general interrupt. */
    *PeriodISR_INTC_SET_EN = PeriodISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PeriodISR_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 PeriodISR_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*PeriodISR_INTC_SET_EN & (uint32)PeriodISR__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: PeriodISR_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_Disable(void)
{
    /* Disable the general interrupt. */
    *PeriodISR_INTC_CLR_EN = PeriodISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PeriodISR_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_SetPending(void)
{
    *PeriodISR_INTC_SET_PD = PeriodISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PeriodISR_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_ClearPending(void)
{
    *PeriodISR_INTC_CLR_PD = PeriodISR__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
