/*******************************************************************************
* File Name: PulsehiISR.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <PulsehiISR.h>

#if !defined(PulsehiISR__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START PulsehiISR_intc` */
    
#include <project.h>

volatile uint16 PulseHighTime;      	// pulsetime

volatile uint8 flgPerdstart;            // Flag indicating + edge of pulsein has occured
volatile uint8 flgPerdend;              // Flag indicating + edge of next pulse has occured, signifying end of pepriod

/* `#END` */

extern cyisraddress CyRamVectors[CYINT_IRQ_BASE + CY_NUM_INTERRUPTS];

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: PulsehiISR_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PulsehiISR_Start(void)
{
    /* For all we know the interrupt is active. */
    PulsehiISR_Disable();

    /* Set the ISR to point to the PulsehiISR Interrupt. */
    PulsehiISR_SetVector(&PulsehiISR_Interrupt);

    /* Set the priority. */
    PulsehiISR_SetPriority((uint8)PulsehiISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    PulsehiISR_Enable();
}


/*******************************************************************************
* Function Name: PulsehiISR_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void PulsehiISR_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    PulsehiISR_Disable();

    /* Set the ISR to point to the PulsehiISR Interrupt. */
    PulsehiISR_SetVector(address);

    /* Set the priority. */
    PulsehiISR_SetPriority((uint8)PulsehiISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    PulsehiISR_Enable();
}


/*******************************************************************************
* Function Name: PulsehiISR_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void PulsehiISR_Stop(void)
{
    /* Disable this interrupt. */
    PulsehiISR_Disable();

    /* Set the ISR to point to the passive one. */
    PulsehiISR_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: PulsehiISR_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for PulsehiISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(PulsehiISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START PulsehiISR_Interrupt` */
    
    if ( ( flgPerdstart == 1 ) && ( flgPerdend == 0 ) ) {    // Ready to take intermeadiate counter value ( - edge of input ) ?
    
        PulseHighTime = Counter_ReadCounter( );             // Read counter when pulse in edge falls
    }
    PWMIN1_ClearInterrupt( );
    return;

    /* `#END` */
}


/*******************************************************************************
* Function Name: PulsehiISR_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling PulsehiISR_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use PulsehiISR_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void PulsehiISR_SetVector(cyisraddress address)
{
    CyRamVectors[CYINT_IRQ_BASE + PulsehiISR__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: PulsehiISR_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress PulsehiISR_GetVector(void)
{
    return CyRamVectors[CYINT_IRQ_BASE + PulsehiISR__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: PulsehiISR_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling PulsehiISR_Start
*   or PulsehiISR_StartEx will override any effect this method would 
*   have had. This method should only be called after PulsehiISR_Start or 
*   PulsehiISR_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 3, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void PulsehiISR_SetPriority(uint8 priority)
{
	uint8 interruptState;
    uint32 priorityOffset = ((PulsehiISR__INTC_NUMBER % 4u) * 8u) + 6u;
    
	interruptState = CyEnterCriticalSection();
    *PulsehiISR_INTC_PRIOR = (*PulsehiISR_INTC_PRIOR & (uint32)(~PulsehiISR__INTC_PRIOR_MASK)) |
                                    ((uint32)priority << priorityOffset);
	CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: PulsehiISR_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 3, 0 being the highest.
*
*******************************************************************************/
uint8 PulsehiISR_GetPriority(void)
{
    uint32 priority;
	uint32 priorityOffset = ((PulsehiISR__INTC_NUMBER % 4u) * 8u) + 6u;

    priority = (*PulsehiISR_INTC_PRIOR & PulsehiISR__INTC_PRIOR_MASK) >> priorityOffset;

    return (uint8)priority;
}


/*******************************************************************************
* Function Name: PulsehiISR_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PulsehiISR_Enable(void)
{
    /* Enable the general interrupt. */
    *PulsehiISR_INTC_SET_EN = PulsehiISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PulsehiISR_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 PulsehiISR_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*PulsehiISR_INTC_SET_EN & (uint32)PulsehiISR__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: PulsehiISR_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PulsehiISR_Disable(void)
{
    /* Disable the general interrupt. */
    *PulsehiISR_INTC_CLR_EN = PulsehiISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PulsehiISR_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PulsehiISR_SetPending(void)
{
    *PulsehiISR_INTC_SET_PD = PulsehiISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PulsehiISR_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PulsehiISR_ClearPending(void)
{
    *PulsehiISR_INTC_CLR_PD = PulsehiISR__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
